Examples
========

On our `repository <https://github.com/domain-independent-dp/didp-rs/tree/main/didppy/examples>`_, we provide example Jupyter notebooks of DP models for combinatorial optimization problems used in this document, :cite:t:`DIDPFirst`, and :cite:t:`DIDPAnytime`.

* `Knapsack problem <https://colab.research.google.com/github/domain-independent-dp/didp-rs/blob/main/didppy/examples/knapsack.ipynb>`_
* `Traveling salesperson problem with time windows (TSPTW) <https://colab.research.google.com/github/domain-independent-dp/didp-rs/blob/main/didppy/examples/tsptw.ipynb>`_ : the DP model is based on :cite:t:`Dumas1995`.
* `Capacitated vehicle routing problem (CVRP) <https://colab.research.google.com/github/domain-independent-dp/didp-rs/blob/main/didppy/examples/cvrp.ipynb>`_ : the DP model is based on :cite:t:`Gromicho2012`.
* `Multi-commodity pick-and-delivery traveling salesperson problem (m-PDTSP) <https://colab.research.google.com/github/domain-independent-dp/didp-rs/blob/main/didppy/examples/m-pdtsp.ipynb>`_
* `Simple assembly line balancing problem (SALBP-1) <https://colab.research.google.com/github/domain-independent-dp/didp-rs/blob/main/didppy/examples/salbp-1.ipynb>`_ : the DP model is based on :cite:t:`Sewell2012`.
* `Bin packing <https://colab.research.google.com/github/domain-independent-dp/didp-rs/blob/main/didppy/examples/bin-packing.ipynb>`_
* `Minimization of open stacks problem (MOSP) <https://colab.research.google.com/github/domain-independent-dp/didp-rs/blob/main/didppy/examples/mosp.ipynb>`_ : the DP model is based on :cite:t:`Chu2009`.
* `Graph-clear <https://colab.research.google.com/github/domain-independent-dp/didp-rs/blob/main/didppy/examples/graph-clear.ipynb>`_ : the DP model is based on the state-based formula in :cite:t:`Morin2018`.
* `Talent scheduling <https://colab.research.google.com/github/domain-independent-dp/didp-rs/blob/main/didppy/examples/talent-scheduling.ipynb>`_ : the DP model is based on :cite:t:`GarciaDeLaBanda2011`.
* `Single machine total weighted tardiness with precedence <https://colab.research.google.com/github/domain-independent-dp/didp-rs/blob/main/didppy/examples/single-machine.ipynb>`_ : the DP model is based on :cite:t:`AbdulRazaq1990`.